@@ -1,32 +1,30 @@
 # Copyright (c) 2021, Google Inc.
 # All rights reserved.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions
-# are met:
-#
-# 1. Redistributions of source code must retain the above copyright notice,
-#    this list of conditions and the following disclaimer.
-#
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions and the following disclaimer in the
-#    documentation and/or other materials provided with the distribution.
-#
-# 3. Neither the name of Google Inc. nor the names of its
-#    contributors may be used to endorse or promote products derived from this
-#    software without specific prior written permission.
-#
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
-# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
-# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
-# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
-# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
-# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
-# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
-# POSSIBILITY OF SUCH DAMAGE.
+# 
+# Redistribution and use in source and binary forms, with or without modification,
+# are permitted provided that the following conditions are met:
+# 
+# 1. Redistributions of source code must retain the above copyright notice, this
+#    list of conditions and the following disclaimer.
+# 
+# 2. Redistributions in binary form must reproduce the above copyright notice,
+#    this list of conditions and the following disclaimer in the documentation
+#    and/or other materials provided with the distribution.
+# 
+# 3. Neither the name of Google Inc. nor the names of its contributors
+#    may be used to endorse or promote products derived from this software without
+#    specific prior written permission.
+# 
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
+# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
+# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
+# ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """Custom metrics and losses for DeepConsensus models."""
 
 from typing import Callable, Optional, Tuple
@@ -162,8 +160,8 @@ def xentropy_ins_cost_fn(y_pred: tf.Tensor, eps=1e-7) -> tf.Tensor:
 class AlignmentLoss(tf.keras.losses.Loss):
   r"""Implements a differentiable alignment loss for DeepConsensus.
 
-  #<internal>
-  #<internal>
+  #TODO: support for from_logits argument.
+  #TODO: support for annealing schedules (depending on DC API?).
 
   Attributes:
     subs_cost_fn: A (batched) function $\Delta^{B \times L_1} \times \Delta^{B
@@ -449,7 +447,7 @@ class AlignmentLoss(tf.keras.losses.Loss):
     input_band = self.weave_band(values, inf)
     subs_band = self.weave_band(subs_costs, inf)
     ins_costs_pad = tf.pad(ins_costs, [[0, 0], [1, 0]], constant_values=0.)
-    # <internal>
+    # TODO: uphere
     insert_expand = tf.tile(
         ins_costs_pad[:, tf.newaxis, :], multiples=[1, len_1 + 1, 1])
     insert_band = self.weave_band(insert_expand, inf)
@@ -494,7 +492,7 @@ class AlignmentLoss(tf.keras.losses.Loss):
     dtype = y_pred.dtype
     # Defines an appropriate large positive float to represent "infinity".
     # inf = tf.dtypes.float16.max if dtype == tf.dtypes.float16 else 1e9
-    inf = tf.convert_to_tensor(1e9, dtype)  # <internal>
+    inf = tf.convert_to_tensor(1e9, dtype)  # TODO: float16 support?
 
     # Removes internal gaps, computes length excl. pad and converts to one-hot.
     y_true, seq_lens = self.preprocess_y_true(y_true)
